;;; init.el --- Init de emacs ordenado -*- lexical-binding: t -*-

;; Author: kj <webmaster@outcontrol.net>
;; URL: https://git.kj2.me/kj/confi-emacs-actual

;;; Commentary:

;; Desde aquí se cargan todos los archivos de la carpeta config.

;;; Code:

;; Mejorar el tiempo de carga
(setq auto-mode-case-fold nil)

(unless (or (daemonp) noninteractive)
  (let ((old-file-name-handler-alist file-name-handler-alist))
    ;; If `file-name-handler-alist' is nil, no 256 colors in TUI
    ;; @see https://emacs-china.org/t/spacemacs-centaur-emacs/3802/839
    (setq file-name-handler-alist
          (unless (display-graphic-p)
            '(("\\(?:\\.tzst\\|\\.zst\\|\\.dz\\|\\.txz\\|\\.xz\\|\\.lzma\\|\\.lz\\|\\.g?z\\|\\.\\(?:tgz\\|svgz\\|sifz\\)\\|\\.tbz2?\\|\\.bz2\\|\\.Z\\)\\(?:~\\|\\.~[-[:alnum:]:#@^._]+\\(?:~[[:digit:]]+\\)?~\\)?\\'" . jka-compr-handler))))
    (add-hook 'emacs-startup-hook
              (lambda ()
                "Recover file name handlers."
                (setq file-name-handler-alist
                      (delete-dups (append file-name-handler-alist
                                           old-file-name-handler-alist)))))))

(setq gc-cons-threshold most-positive-fixnum
      gc-cons-percentage 0.5)
(add-hook 'emacs-startup-hook
          (lambda ()
            "Recover GC values after startup."
            (setq gc-cons-threshold 800000
                  gc-cons-percentage 0.1)))

;; Cargar configuraciones

(add-to-list 'load-path (concat user-emacs-directory "configs"))

;; Paquetes base
(require 'init-base)
(require 'init-extensions)
(require 'init-functions)
(require 'init-org)
;; (require 'init-lsp)
(require 'init-eglot)
(require 'init-company)
(require 'init-treemacs)
;;(require 'init-ctags)
(require 'init-ivy)
(require 'init-keys)

;; Lenguajes
(require 'lang-php)
(require 'lang-js)
(require 'lang-go)
(require 'lang-rust)

(provide 'init)
;;; init.el ends here
